.. index::
   single: pshell; --help

.. _pshell_script:

.. autoprogram:: pyramid.scripts.pshell:PShellCommand.parser
    :prog: pshell

.. seealso:: :ref:`interactive_shell` and :ref:`running-pscripts`.
